Data Operations

#### Pacote construído para a manipulação de um banco de dados e retorno de resultados, baseado nas condições definidas pelo usuário.


#### Exemplos de Aplicações:


#### Instalação: 

    pip install data_operations


#### Uso: